@@ -1,5 +1,5 @@
 # Chunking utilities for bit and ff
-# (c) 2007-2009 Jens Oehlschgel
+# (c) 2007-2009 Jens Oehlschägel
 # Licence: GPL2
 # Provided 'as is', use at your own risk
 # Created: 2007-09-03
@@ -31,7 +31,7 @@
 #! \details{
 #!   Tries to have \code{rb==0} or \code{rb} as close to \code{b} as possible while guaranteing that \code{rb < b && (b - rb) <= min(nb, b)}
 #! }
-#! \author{ Jens Oehlschlgel }
+#! \author{ Jens Oehlschlägel }
 #! \seealso{ \code{\link{repfromto}}, \code{\link[ff]{ffvecapply}} }
 #! \examples{
 #!   bbatch(100, 24)
@@ -111,7 +111,7 @@ bbatch <- function(N,B){
 #! \value{
 #!   a vector of length \code{from - to + 1}
 #! }
-#! \author{ Jens Oehlschlgel }
+#! \author{ Jens Oehlschlägel }
 #! \seealso{ \code{\link{rep}}, \code{\link[ff]{ffvecapply}} }
 #! \examples{
 #!   message("a simple example")
@@ -144,8 +144,7 @@ repfromto <- function(x, from, to){
     }
     a <- attributes(x[1])
     a$names <- NULL
-    #attributes(ret) <- a
-    setattributes(ret, a)
+    attributes(ret) <- a
     return(ret)
   }else{
     return(NA[from:to])
@@ -260,7 +259,7 @@ if (FALSE){
 #! \value{
 #!   \code{chunk.default} returns a list of \code{\link{ri}} objects representing chunks of subscripts
 #! }
-#! \author{ Jens Oehlschlgel }
+#! \author{ Jens Oehlschlägel }
 #! \seealso{ \code{\link{ri}},  \code{\link[base]{seq}}, \code{\link{bbatch}} }
 #! \examples{
 #!   chunk(1, 100, by=30)
@@ -427,7 +426,7 @@ chunk.default <- function(
 #!   if \code{concat==TRUE } and \code{eval==FALSE} a single call generating the concatenated sequences \cr
 #!   if \code{concat==TRUE } and \code{eval==TRUE } an integer vector of concatentated sequences
 #! }
-#! \author{ Angelo Canty, Jens Oehlschlgel }
+#! \author{ Angelo Canty, Jens Oehlschlägel }
 #! \seealso{ \code{\link{:}}, \code{\link{seq}}, \code{\link{sequence}} }
 #! \examples{
 #!   sequence(c(3,4))
